@@ -251,7 +251,7 @@ function [stats, bootstat, X] = bootclust (x, nboot, bootfun, alpha, ...
   
   % Initialise the random number generator with the SEED (if provided)
   if ( (nargin > 6) && (~ isempty (seed)) )
-    boot (1, 1, true, seed);
+    boot (1, 1, false, seed);
   end
 
   % Evaluate NPROC input argument
@@ -737,10 +737,10 @@ function print_output (stats, nboot, nalpha, alpha, probs, m, bootfun_str, ...
     fprintf ('Bootstrap settings: \n');
     fprintf (' Function: %s\n', bootfun_str);
     if loo
-      fprintf (' Resampling method: Balanced, bootknife %s resampling \n', ...
+      fprintf (' Resampling method: Balanced, %s bootknife resampling \n', ...
                bootname);
     else
-      fprintf (' Resampling method: Balanced, bootstrap %s resampling \n', ...
+      fprintf (' Resampling method: Balanced, %s bootstrap resampling \n', ...
                bootname);
     end
     fprintf (' Number of resamples: %u \n', nboot(1));
