@@ -21,7 +21,7 @@
 %     following statistics:
 %        - original: the original estimate(s) calculated by BOOTFUN and the DATA
 %        - bias: bootstrap bias of the estimate(s)
-%        - std_error: bootstrap estandard error of the estimate(s)
+%        - std_error: bootstrap standard error of the estimate(s)
 %        - CI_lower: lower bound(s) of the 95% bootstrap confidence interval
 %        - CI_upper: upper bound(s) of the 95% bootstrap confidence interval
 %
@@ -50,7 +50,9 @@
 %        one of the same). If BOOTFUN is @mean or 'mean', narrowness bias of
 %        the confidence intervals for single bootstrap are reduced by expanding
 %        the probabilities of the percentiles using Student's t-distribution
-%        [7]. By default, BOOTFUN is @mean.
+%        [7]. To compute confidence intervals for the mean without this
+%        correction for narrowness bias, define the mean within an anonymous
+%        function instead (e.g. @(x) mean(x)). By default, BOOTFUN is @mean.
 %
 %     'bootknife ({D1, D2, ...}, NBOOT, BOOTFUN)' resamples from the rows of D1,
 %     D2 etc and the resamples are passed to BOOTFUN as multiple data input
@@ -687,7 +689,7 @@ function [stats, bootstat, bootsam] = bootknife (x, nboot, bootfun, alpha, ...
     % Bootstrap bias estimation
     bias = mean (bootstat, 2) - T0;
     % Bootstrap standard error
-    se = std (bootstat, 0, 2);  % Unbiased since we used bootknife resampling
+    se = std (bootstat, 0, 2);  % Unbiased if we use bootknife resampling
     if (~ isnan (alpha))
       % If bootfun is the arithmetic mean, expand the probabilities of the 
       % percentiles using Student's t-distribution
@@ -1375,18 +1377,18 @@ end
 %!
 %! % Calculations using the 'boot' and 'bootstrap' packages in R
 %! % 
-%! % library (boot)       % Functions from Davison and Hinkley (1997)
-%! % A <- c(48,36,20,29,42,42,20,42,22,41,45,14,6, ...
+%! % library (boot)       # Functions from Davison and Hinkley (1997)
+%! % A <- c(48,36,20,29,42,42,20,42,22,41,45,14,6,
 %! %        0,33,28,34,4,32,24,47,41,24,26,30,41);
 %! % n <- length(A)
 %! % var.fun <- function (d, i) { 
-%! %        % Function to compute the population variance
+%! %        # Function to compute the population variance
 %! %        n <- length (d); 
 %! %        return (var (d[i]) * (n - 1) / n) };
 %! % boot.fun <- function (d, i) {
-%! %        % Compute the estimate
+%! %        # Compute the estimate
 %! %        t <- var.fun (d, i);
-%! %        % Compute sampling variance of the estimate using Tukey's jackknife
+%! %        # Compute sampling variance of the estimate using Tukey's jackknife
 %! %        n <- length (d);
 %! %        U <- empinf (data=d[i], statistic=var.fun, type="jack", stype="i");
 %! %        var.t <- sum (U^2 / (n * (n - 1)));
@@ -1399,7 +1401,7 @@ end
 %! % ci4 <- boot.ci (var.boot, conf=0.90, type="bca")
 %! % ci5 <- boot.ci (var.boot, conf=0.90, type="stud")
 %! %
-%! % library (bootstrap)  % Functions from Efron and Tibshirani (1993)
+%! % library (bootstrap)  # Functions from Efron and Tibshirani (1993)
 %! % set.seed(1);
 %! % ci4a <- bcanon (A, 19999, var.fun, alpha=c(0.05,0.95))
 %! % set.seed(1); 
