@@ -41,6 +41,24 @@ d = struct;
 d.dir = inst_dir;
 post_install (d);
 
+% Check if the user has run the make script
+inst_files = dir (inst_dir);
+if (all (arrayfun (@(name) ismember (sprintf ('%s.%s', name{:}, mexext), ...
+                                 {inst_files.name}), {'boot', 'smoothmedian'})))
+  try
+    boot (1, 1);
+    smoothmedian (1);
+    make_done = true;
+  catch
+    make_done = false;
+  end
+else
+  make_done = false;
+end
+if (~ make_done)
+  warning ('For optimal performance, run the ''make'' command to copy or compile the appropriate binaries')
+end
+
 % Clean up
-clear info isoctave S comment octaverc fid msg inst_dir d
+clear info isoctave S comment octaverc fid msg inst_dir inst_files d make_done
 
